Learn R Programming

rdataretriever (version 3.1.1)

dataset_names: Name all available dataset scripts.

Description

Additional information on the available datasets can be found at url https://retriever.readthedocs.io/en/latest/datasets.html

Usage

dataset_names()

Arguments

Value

returns a character vector with the available datasets for download

Examples

Run this code
if (FALSE) {
rdataretriever::dataset_names()
}

Run the code above in your browser using DataLab