Learn R Programming

rdataretriever (version 3.1.1)

datasets: Name all available dataset scripts.

Description

Additional information on the available datasets can be found at url https://retriever.readthedocs.io/en/latest/datasets.html

Usage

datasets(keywords = "", licenses = "")

Value

returns a character vector with the available datasets for download

Returns the names of all available dataset scripts

Arguments

keywords

search all datasets by keywords

licenses

search all datasets by licenses

Examples

Run this code
if (FALSE) {
rdataretriever::datasets()
}

Run the code above in your browser using DataLab