Learn R Programming

rdataretriever (version 3.1.1)

display_all_rdataset_names: Displays the list of rdataset names present in the list of packages provided

Description

Can take a list of packages, or NULL or a string 'all' for all rdataset packages and datasets

Usage

display_all_rdataset_names(package_name = NULL)

Value

No return value, displays the list of rdataset names present

Arguments

package_name

print datasets in the package, default to print rdataset and all to print all

Examples

Run this code
if (FALSE) {
rdataretriever::display_all_rdataset_names()
}

Run the code above in your browser using DataLab