Learn R Programming

rdataretriever (version 3.1.1)

install: Install datasets via the Data Retriever (deprecated).

Description

Data is stored in either CSV files or one of the following database management systems: MySQL, PostgreSQL, SQLite, or Microsoft Access.

Usage

install(
  dataset,
  connection,
  db_file = NULL,
  conn_file = NULL,
  data_dir = ".",
  log_dir = NULL
)

Value

No return value, main install function

Arguments

dataset

the name of the dataset that you wish to download

connection

what type of database connection should be used. The options include: mysql, postgres, sqlite, msaccess, or csv'

db_file

the name of the datbase file the dataset should be loaded into

conn_file

the path to the .conn file that contains the connection configuration options for mysql and postgres databases. This defaults to mysql.conn or postgres.conn respectively. The connection file is a file that is formated in the following way:

hostmy_server@my_host.com
portmy_port_number
usermy_user_name
passwordmy_password

data_dir

the location where the dataset should be installed. Only relevant for csv connection types. Defaults to current working directory

log_dir

the location where the retriever log should be stored if the progress is not printed to the console

Examples

Run this code
if (FALSE) {
rdataretriever::install("iris", "csv")
}

Run the code above in your browser using DataLab