powered by
Data is stored in MySQL database
install_mysql( dataset, user = "root", password = "", host = "localhost", port = 3306, database_name = "{db}", table_name = "{db}.{table}", debug = FALSE, use_cache = TRUE, force = FALSE, hash_value = NULL )
No return value, installs datasets into MySQL database
the name of the dataset that you wish to install or path to a committed dataset zip file
username for database connection
password for database connection
hostname for connection
port number for connection
database name in which dataset will be installed
table name specified especially for datasets containing one file
setting TRUE helps in debugging in case of errors
setting FALSE reinstalls scripts even if they are already installed
setting TRUE doesn't prompt for confirmation while installing committed datasets when changes are discovered in environment
the hash value of committed dataset when installing from provenance directory
if (FALSE) { rdataretriever::install_mysql(dataset = "portal", user = "postgres", password = "abcdef") }
Run the code above in your browser using DataLab