install the python module `retriever`
install_retriever(method = "auto", conda = "auto")No return value, install the python module `retriever`
Installation method. By default, "auto" automatically finds a method that will work in the local environment. Change the default to force a specific installation method. Note that the "virtualenv" method is not available on Windows.
The path to a conda executable. Use "auto" to allow
reticulate to automatically find an appropriate conda binary.
See Finding Conda and conda_binary() for more details.