powered by
Additional information on the available datasets can be found at url https://retriever.readthedocs.io/en/latest/datasets.html
dataset_names()
returns a character vector with the available datasets for download
if (FALSE) { rdataretriever::dataset_names() }
Run the code above in your browser using DataLab