powered by
Additional information on the available datasets can be found at url https://retriever.readthedocs.io/en/latest/datasets.html
datasets(keywords = "", licenses = "")
returns a character vector with the available datasets for download
Returns the names of all available dataset scripts
search all datasets by keywords
search all datasets by licenses
if (FALSE) { rdataretriever::datasets() }
Run the code above in your browser using DataLab