powered by
Can take a list of packages, or NULL or a string 'all' for all rdataset packages and datasets
display_all_rdataset_names(package_name = NULL)
No return value, displays the list of rdataset names present
print datasets in the package, default to print rdataset and all to print all
if (FALSE) { rdataretriever::display_all_rdataset_names() }
Run the code above in your browser using DataLab